# IADS: Customized and Simplified package for Core Supervised Learning Algorithms

## Setup conda environment
```bash
conda create -n iads python=3.10 -y
conda activate iads
pip install -r requirements.txt
```
